# TBRIDGE

***T***esting ***BRI***ghtness ***D***eviations in **G**alaxy Profile **E**xtractions

Tbridge is a testing suite for images and catalogues of astronomical information, 
using differences between the extracted profiles of a model galaxy and that same model 
added to various backgrounds. 

